R/FunctionalSpectra.R
preprocessGeneList.Rd
This function preprocess gene list for futhur process
preprocessGeneList(geneList)
a named vector containing the value of gene expression
a named vecter containing the value of gene expression
if (FALSE) { # \dontrun{ geneList <- setNames(rnorm(10), paste0("G", seq_len(10))) preprocessGeneList(geneList) } # }